<h1 align="center">Wrench Code Library</h1>

<p align="center">
  <br>
  <a href="https://pypi.org/project/WrenchCL/"><img src="https://badge.fury.io/py/WrenchCL.svg" alt="PyPI version" height="20"/></a>
  <img src="https://img.shields.io/badge/python-3.x-blue" alt="Python Version" height="20"/>
  <a href="https://github.com/Kydoimos97"><img src="https://img.shields.io/badge/maintainer-Kydoimos97-yellow" alt="Maintainer" height="20"/></a>
  <br><br>
  <a href="https://github.com/WrenchAI/WrenchCL/stargazers"><img src="https://img.shields.io/github/stars/WrenchAI/WrenchCL.svg" alt="GitHub Stars" height="20"/></a>
  <a href="https://github.com/WrenchAI/WrenchCL/network/members"><img src="https://img.shields.io/github/forks/WrenchAI/WrenchCL.svg" alt="GitHub Forks" height="20"/></a>
  <a href="https://github.com/WrenchAI/WrenchCL/issues"><img src="https://img.shields.io/github/issues/WrenchAI/WrenchCL.svg" alt="GitHub Issues" height="20"/></a>
  <a href="https://github.com/WrenchAI/WrenchCL/pulls"><img src="https://img.shields.io/github/issues-pr/WrenchAI/WrenchCL.svg" alt="GitHub Pull Requests" height="20"/></a>

  
</p>

## Description

This is a code library designed to improve code reusability and standardize access to APIs, RDS, and logging functionalities.

**Pypi Link: [https://pypi.org/project/WrenchCL/](https://pypi.org/project/WrenchCL/)**

## Installation

To install the package, simply run:

```bash
pip install WrenchCL
```
